==> jc-1.4.0.tar.gz: javax/security/sasl/RealmChoiceCallback.h <==
// public class javax.security.sasl.RealmChoiceCallback

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2f9bd66639308f6a javax_security_auth_callback_ChoiceCallback
// @dep_class 888ea3d821744ae javax_security_sasl_RealmChoiceCallback

// header file dependencies
// @dep_header javax_security_auth_callback_ChoiceCallback

#include "javax/security/auth/callback/ChoiceCallback.h"

#ifndef _JC_javax_security_sasl_RealmChoiceCallback_H_
#define _JC_javax_security_sasl_RealmChoiceCallback_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_sasl_RealmChoiceCallback$sub_refs	_jc_javax_security_sasl_RealmChoiceCallback$sub_refs;
typedef struct _jc_javax_security_sasl_RealmChoiceCallback$sub_nonrefs	_jc_javax_security_sasl_RealmChoiceCallback$sub_nonrefs;
typedef struct _jc_javax_security_sasl_RealmChoiceCallback$refs	_jc_javax_security_sasl_RealmChoiceCallback$refs;
typedef struct _jc_javax_security_sasl_RealmChoiceCallback$nonrefs	_jc_javax_security_sasl_RealmChoiceCallback$nonrefs;
typedef struct _jc_javax_security_sasl_RealmChoiceCallback$object	_jc_javax_security_sasl_RealmChoiceCallback$object;

typedef const struct _jc_javax_security_sasl_RealmChoiceCallback$vmethods	_jc_javax_security_sasl_RealmChoiceCallback$vmethods;
typedef const struct _jc_javax_security_sasl_RealmChoiceCallback$vtable	_jc_javax_security_sasl_RealmChoiceCallback$vtable;
typedef const struct _jc_javax_security_sasl_RealmChoiceCallback$vtype	_jc_javax_security_sasl_RealmChoiceCallback$vtype;

// Constructors
extern void _jc_javax_security_sasl_RealmChoiceCallback$method$_init$6c1a77efd87707d9(_jc_env *, struct _jc_javax_security_sasl_RealmChoiceCallback$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *, jint, jboolean);

// Virtual methods structure
struct _jc_javax_security_sasl_RealmChoiceCallback$vmethods {
};

// Vtable
struct _jc_javax_security_sasl_RealmChoiceCallback$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_callback_ChoiceCallback$vmethods	javax_security_auth_callback_ChoiceCallback;
	_jc_javax_security_sasl_RealmChoiceCallback$vmethods	javax_security_sasl_RealmChoiceCallback;
};

// Vtype
struct _jc_javax_security_sasl_RealmChoiceCallback$vtype {
	_jc_type			type;
	_jc_javax_security_sasl_RealmChoiceCallback$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_sasl_RealmChoiceCallback$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_sasl_RealmChoiceCallback$refs {
    _jc_javax_security_sasl_RealmChoiceCallback$sub_refs	javax_security_sasl_RealmChoiceCallback;
    _jc_javax_security_auth_callback_ChoiceCallback$sub_refs	javax_security_auth_callback_ChoiceCallback;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_sasl_RealmChoiceCallback$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_sasl_RealmChoiceCallback$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_callback_ChoiceCallback$sub_nonrefs	javax_security_auth_callback_ChoiceCallback;
    _jc_javax_security_sasl_RealmChoiceCallback$sub_nonrefs	javax_security_sasl_RealmChoiceCallback;
};

// Object instance structure
struct _jc_javax_security_sasl_RealmChoiceCallback$object {
	_jc_javax_security_sasl_RealmChoiceCallback$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_sasl_RealmChoiceCallback$vtype	*vtype;
	_jc_javax_security_sasl_RealmChoiceCallback$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_sasl_RealmChoiceCallback$vtype _jc_javax_security_sasl_RealmChoiceCallback$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_sasl_RealmChoiceCallback, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_sasl_RealmChoiceCallback$class_object;

#endif	/* _JC_javax_security_sasl_RealmChoiceCallback_H_ */

==> jc-1.4.6.tar.gz: javax/security/sasl/RealmChoiceCallback.h <==
// public class javax.security.sasl.RealmChoiceCallback

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2f9bd66639308f6a javax_security_auth_callback_ChoiceCallback
// @dep_class 888ea3d821744ae javax_security_sasl_RealmChoiceCallback

// header file dependencies
// @dep_header javax_security_auth_callback_ChoiceCallback

#include "javax/security/auth/callback/ChoiceCallback.h"

#ifndef _JC_javax_security_sasl_RealmChoiceCallback_H_
#define _JC_javax_security_sasl_RealmChoiceCallback_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_sasl_RealmChoiceCallback$sub_refs	_jc_javax_security_sasl_RealmChoiceCallback$sub_refs;
typedef struct _jc_javax_security_sasl_RealmChoiceCallback$sub_nonrefs	_jc_javax_security_sasl_RealmChoiceCallback$sub_nonrefs;
typedef struct _jc_javax_security_sasl_RealmChoiceCallback$refs	_jc_javax_security_sasl_RealmChoiceCallback$refs;
typedef struct _jc_javax_security_sasl_RealmChoiceCallback$nonrefs	_jc_javax_security_sasl_RealmChoiceCallback$nonrefs;
typedef struct _jc_javax_security_sasl_RealmChoiceCallback$object	_jc_javax_security_sasl_RealmChoiceCallback$object;

typedef const struct _jc_javax_security_sasl_RealmChoiceCallback$vmethods	_jc_javax_security_sasl_RealmChoiceCallback$vmethods;
typedef const struct _jc_javax_security_sasl_RealmChoiceCallback$vtable	_jc_javax_security_sasl_RealmChoiceCallback$vtable;
typedef const struct _jc_javax_security_sasl_RealmChoiceCallback$vtype	_jc_javax_security_sasl_RealmChoiceCallback$vtype;

// Constructors
extern void _jc_javax_security_sasl_RealmChoiceCallback$method$_init$6c1a77efd87707d9(_jc_env *, struct _jc_javax_security_sasl_RealmChoiceCallback$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *, jint, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_security_sasl_RealmChoiceCallback$vmethods {
};

// Vtable
struct _jc_javax_security_sasl_RealmChoiceCallback$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_callback_ChoiceCallback$vmethods	javax_security_auth_callback_ChoiceCallback;
	_jc_javax_security_sasl_RealmChoiceCallback$vmethods	javax_security_sasl_RealmChoiceCallback;
};

// Vtype
struct _jc_javax_security_sasl_RealmChoiceCallback$vtype {
	_jc_type			type;
	_jc_javax_security_sasl_RealmChoiceCallback$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_sasl_RealmChoiceCallback$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_sasl_RealmChoiceCallback$refs {
    _jc_javax_security_sasl_RealmChoiceCallback$sub_refs	javax_security_sasl_RealmChoiceCallback;
    _jc_javax_security_auth_callback_ChoiceCallback$sub_refs	javax_security_auth_callback_ChoiceCallback;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_sasl_RealmChoiceCallback$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_sasl_RealmChoiceCallback$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_callback_ChoiceCallback$sub_nonrefs	javax_security_auth_callback_ChoiceCallback;
    _jc_javax_security_sasl_RealmChoiceCallback$sub_nonrefs	javax_security_sasl_RealmChoiceCallback;
};

// Object instance structure
struct _jc_javax_security_sasl_RealmChoiceCallback$object {
	_jc_javax_security_sasl_RealmChoiceCallback$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_sasl_RealmChoiceCallback$vtype	*vtype;
	_jc_javax_security_sasl_RealmChoiceCallback$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_sasl_RealmChoiceCallback$vtype _jc_javax_security_sasl_RealmChoiceCallback$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_sasl_RealmChoiceCallback, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_sasl_RealmChoiceCallback$class_object;

#endif	/* _JC_javax_security_sasl_RealmChoiceCallback_H_ */
